Account class

Annotations
  • @JsonSerializable.new()

Constructors

Account({required String id, required String provider, required DateTime createdAt, required DateTime updatedAt})
Account.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
provider → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited