TokenRefresh class

Annotations
  • @JsonSerializable.new()

Constructors

TokenRefresh({required String tokenType, required String idToken, required String accessToken, required String refreshToken, required DateTime accessTokenExpiresAt, required DateTime refreshTokenExpiresAt})
TokenRefresh.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken → String
final
accessTokenExpiresAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String
final
refreshToken → String
final
refreshTokenExpiresAt → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited