UserWrapper<T extends User> class

A generic wrapper for User model that allows custom user model types

Constructors

UserWrapper({required T user, required String token})
UserWrapper.fromJson(Map<String, dynamic> json, T fromJsonT(Map<String, dynamic>))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final
user → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited