CreateUserResponse<T extends User> class

Inheritance

Constructors

CreateUserResponse({required T user})
CreateUserResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Map<String, dynamic>))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → T
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T value)) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited