ListUsersResponse<T> class

Constructors

ListUsersResponse({required int total, required int limit, required int offset, required List<T> users})
ListUsersResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Map<String, dynamic> json))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
final
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final
users → List<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited