SetRoleResponse<T extends User> class

Implementers

Constructors

SetRoleResponse({required T user})
SetRoleResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Map<String, dynamic> json))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T value)) → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited