UpdateOrganizationResponse class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

UpdateOrganizationResponse({required String id, required String name, required DateTime? createdAt, required String slug, required Map<String, dynamic> metadata})
UpdateOrganizationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
finalinherited
metadata → Map<String, dynamic>
finalinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited