UsernamePlugin<T extends User> class

Username plugin for better-auth.

Requires username plugin to be installed server side.

This plugin allows users to sign in using their username and password instead of email and password.

Inheritance

Constructors

UsernamePlugin()

Properties

dio ↔ Dio
latefinalinherited
fromJsonUser ↔ T Function(Map<String, dynamic> json)
latefinalinherited
getOptions Future<Options> Function({bool isTokenRequired})
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenStore TokenStore
latefinalinherited

Methods

initialize({required Dio dio, required Future<Options> getOptions({bool isTokenRequired}), required TokenStore tokenStore, required T fromJsonUser(Map<String, dynamic> json)}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn({required String username, required String password, bool? rememberMe}) Future<UserAndTokenResponse>
Sign in with username and password
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited